# MDTCollections

[ ![Codeship Status for avirshup/mdtcollections](https://app.codeship.com/projects/0038bdc0-24a2-0136-6dbc-6ee515ac7d80/status?branch=master)](https://app.codeship.com/projects/286368)

Various collection classes factored out from https://github.com/autodesk/molecule-design-toolkit .

```
pip install mdtcollections
```

# License

Apache 2.0

Copyright 2016-2018 Autodesk Inc. Copyright 2018 project contributors.
